# ADC-compliance-checker
Arctic Data Centre compliance checker is a python based tool for those wanting to submit data to the Artic Data Centre. The python module can be used to check if files fullfill the rquirements listed [here](https://adc.met.no/node/4).

The compliance checker can be used in combination with CF and ACDD chekcers to enusre NetCDF files adhere to the FAIR principles for data management.

## Usage

### Command Line


### As a Python Package